@@ -27,10 +27,25 @@ from easydev.tools import check_param_in_list, swapdict, check_range
 from colormap.xfree86 import XFree86_colors
 
 
-__all__ = ["HEX", "Color", "hex2web", "web2hex", "hex2rgb", "hex2dec",
-    "rgb2hex", "rgb2hsv", "hsv2rgb", "rgb2hls", "hls2rgb","yuv2rgb", "rgb2yuv",
-    "to_intensity", "yuv2rgb_int", "rgb2yuv_int", "Colormap"
-    ]
+__all__ = [
+    "HEX",
+    "Color",
+    "hex2web",
+    "web2hex",
+    "hex2rgb",
+    "hex2dec",
+    "rgb2hex",
+    "rgb2hsv",
+    "hsv2rgb",
+    "rgb2hls",
+    "hls2rgb",
+    "yuv2rgb",
+    "rgb2yuv",
+    "to_intensity",
+    "yuv2rgb_int",
+    "rgb2yuv_int",
+    "Colormap",
+]
 
 
 def hex2web(hexa):
@@ -91,7 +106,7 @@ def hex2rgb(hexcolor, normalise=False):
         :func:`hls2rgb`
     """
     hexcolor = HEX().get_standard_hex_color(hexcolor)[1:]
-    r, g, b =  int(hexcolor[0:2], 16), int(hexcolor[2:4], 16), int(hexcolor[4:6], 16)
+    r, g, b = int(hexcolor[0:2], 16), int(hexcolor[2:4], 16), int(hexcolor[4:6], 16)
     if normalise:
         r, g, b = _normalise(r, g, b)
     return r, g, b
@@ -124,7 +139,7 @@ def rgb2hex(r, g, b, normalised=False):
     check_range(r, 0, 255)
     check_range(g, 0, 255)
     check_range(b, 0, 255)
-    return '#%02X%02X%02X' % (r, g, b)
+    return "#%02X%02X%02X" % (r, g, b)
 
 
 def rgb2hls(r, g, b, normalised=True):
@@ -155,7 +170,7 @@ def rgb2hls(r, g, b, normalised=True):
     check_range(r, 0, upper)
     check_range(g, 0, upper)
     check_range(b, 0, upper)
-    if normalised==False:
+    if normalised == False:
         r, g, b = _normalise(r, g, b)
     h, l, s = colorsys.rgb_to_hls(r, g, b)
     return h, l, s
@@ -189,10 +204,10 @@ def rgb2hsv(r, g, b, normalised=True):
     check_range(r, 0, upper)
     check_range(g, 0, upper)
     check_range(b, 0, upper)
-    if normalised==False:
+    if normalised == False:
         r, g, b = _normalise(r, g, b)
     h, s, v = colorsys.rgb_to_hsv(r, g, b)
-    return h,s,v
+    return h, s, v
 
 
 def hsv2rgb(h, s, v, normalised=True):
@@ -271,9 +286,10 @@ def hls2rgb(h, l, s, normalised=True):
 
 def hex2dec(data):
     """convert hexadecimal string (data) into a float in the [0-65536] inclusive range"""
-    if data[0] == '#':
-        data.replace('#', '')
-    return int(data, 16)/255.
+    if data[0] == "#":
+        data.replace("#", "")
+    return int(data, 16) / 255.0
+
 
 def rgb2yuv(r, g, b):
     """Convert RGB triplet into YUV
@@ -289,13 +305,13 @@ def rgb2yuv(r, g, b):
     check_range(g, 0, 1)
     check_range(b, 0, 1)
 
-    #y = int(0.299 * r + 0.587 * g + 0.114 * b)
-    #u = int(-0.14713 * r + -0.28886 * g + 0.436 * b)
-    #v = int(0.615 * r + -0.51499 * g + -0.10001 * b)
+    # y = int(0.299 * r + 0.587 * g + 0.114 * b)
+    # u = int(-0.14713 * r + -0.28886 * g + 0.436 * b)
+    # v = int(0.615 * r + -0.51499 * g + -0.10001 * b)
 
     y = 0.299 * r + 0.587 * g + 0.114 * b
-    u = -32591.0/221500.0 * r + -63983.0/221500.0 * g + 0.436 * b
-    v = 0.615 * r + -72201./140200 * g + -7011/70100. * b
+    u = -32591.0 / 221500.0 * r + -63983.0 / 221500.0 * g + 0.436 * b
+    v = 0.615 * r + -72201.0 / 140200 * g + -7011 / 70100.0 * b
     return (y, u, v)
 
 
@@ -307,10 +323,10 @@ def yuv2rgb(y, u, v):
     .. warning:: expected input must be between 0 and 255 (not normalised)
 
     """
-    check_range(y, 0,1)
+    check_range(y, 0, 1)
     check_range(u, 0, 1)
     check_range(v, 0, 1)
-    A, B, C, D = 701.0/615.0, 25251.0/63983.0, 209599.0/361005.0, 443.0/218.0
+    A, B, C, D = 701.0 / 615.0, 25251.0 / 63983.0, 209599.0 / 361005.0, 443.0 / 218.0
     r = y + A * v
     g = y - B * u - C * v
     b = y + D * u
@@ -330,8 +346,8 @@ def rgb2yuv_int(r, g, b):
     check_range(b, 0, 255)
 
     y = int(0.299 * r + 0.587 * g + 0.114 * b)
-    u = int(-32591.0/221500.0 * r + -63983.0/221500.0 * g + 0.436 * b)
-    v = int(0.615 * r + -72201./140200 * g + -7011/70100. * b)
+    u = int(-32591.0 / 221500.0 * r + -63983.0 / 221500.0 * g + 0.436 * b)
+    v = int(0.615 * r + -72201.0 / 140200 * g + -7011 / 70100.0 * b)
 
     return (y, u, v)
 
@@ -356,17 +372,17 @@ def yuv2rgb_int(y, u, v):
 def _denormalise(r, g, b, mode="rgb"):
     check_param_in_list(mode, ["rgb", "hls", "hsv"])
     if mode == "rgb":
-        return r*255., g*255., b*255.
+        return r * 255.0, g * 255.0, b * 255.0
     elif mode in ["hls", "hsv"]:
-        return r*360., g*100., b*100.
+        return r * 360.0, g * 100.0, b * 100.0
 
 
 def _normalise(r, g, b, mode="rgb"):
     check_param_in_list(mode, ["rgb", "hls", "hsv"])
     if mode == "rgb":
-        return r/255., g/255., b/255.
+        return r / 255.0, g / 255.0, b / 255.0
     elif mode in ["hls", "hsv"]:
-        return r/360., g/100., b/100.
+        return r / 360.0, g / 100.0, b / 100.0
 
 
 def to_intensity(n):
@@ -391,6 +407,7 @@ class HEX(object):
         True
 
     """
+
     def __init__(self):
         pass
 
@@ -418,13 +435,13 @@ class HEX(object):
         By standard, we mean a string that starts with # sign followed by 6
         character, e.g. #AABBFF
         """
-        if isinstance(value, str)==False:
+        if isinstance(value, str) == False:
             raise TypeError("value must be a string")
         if len(value) <= 3:
             raise ValueError("input string must be of type 0xFFF, 0xFFFFFF or #FFF or #FFFFFF")
 
         if value.startswith("0x") or value.startswith("0X"):
-            value =  value[2:]
+            value = value[2:]
         elif value.startswith("#"):
             value = value[1:]
         else:
@@ -437,9 +454,9 @@ class HEX(object):
                 raise ValueError("Found invalid hexa character {0}".format(x))
 
         if len(value) == 6 or len(value) == 8:
-            value  = "#" + value[0:6]
+            value = "#" + value[0:6]
         elif len(value) == 3:
-            value = "#" + value[0]*2 + value[1]*2 + value[2]*2
+            value = "#" + value[0] * 2 + value[1] * 2 + value[2] * 2
         else:
             raise ValueError("hexa string should be 3, 6 or 8 digits. if 8 digits, last 2 are ignored")
         return value
@@ -482,18 +499,19 @@ class Color(HEX):
     provided as "Spring Green", "spring green", "springgreen" or "SpringGreen".
 
     """
+
     # Get official color names
     colors = XFree86_colors.copy()
     # add color names without spaces
-    aliases = dict([(x.replace(" ", ""),x) for x in colors.keys() if " " in x])
+    aliases = dict([(x.replace(" ", ""), x) for x in colors.keys() if " " in x])
     # add color names without spaces in lower cases
-    aliases.update([(x.replace(" ", "").lower(),x) for x in colors.keys() if " " in x])
+    aliases.update([(x.replace(" ", "").lower(), x) for x in colors.keys() if " " in x])
     # add color names in lower case
-    aliases.update(dict([(x.lower(),x) for x in colors.keys()]))
-    aliases.update(dict([(x,x) for x in colors.keys()]))
+    aliases.update(dict([(x.lower(), x) for x in colors.keys()]))
+    aliases.update(dict([(x, x) for x in colors.keys()]))
 
     # keep track of all possible names
-    color_names = sorted(list(set(list(colors.keys()) +list( aliases.keys()))))
+    color_names = sorted(list(set(list(colors.keys()) + list(aliases.keys()))))
 
     def __init__(self, name=None, rgb=None, hls=None, hsv=None):
         super(Color, self).__init__()
@@ -512,7 +530,7 @@ class Color(HEX):
                 # if not, then, the user probably provided a valid color name
                 # the property will check the validity.
                 self.name = name[:]
-                #all other input parameters are ignored
+                # all other input parameters are ignored
         elif name == None:
             if rgb:
                 self.rgb = rgb
@@ -529,17 +547,20 @@ class Color(HEX):
 
     def _get_name(self):
         return self._name
+
     def _set_name(self, name):
         check_param_in_list(name, self.color_names)
         name = self.aliases[name]
         self._name = name
         # set hex and rgb at the same time based on the name
         self.hex = self.colors[name]
+
     name = property(_get_name, _set_name)
     color = property(_get_name, _set_name)
 
     def _get_hex(self):
         return self._hex
+
     def _set_hex(self, value):
         # hex is an approximation made of 255 bits so do not define rgb here
         if self.is_valid_hex_color(value):
@@ -553,109 +574,126 @@ class Color(HEX):
         else:
             # just to warn the user
             self.get_standard_hex_color(value)
-    hex = property(_get_hex, _set_hex, 
-            doc="getter/setter the hexadecimal value.")
+
+    hex = property(_get_hex, _set_hex, doc="getter/setter the hexadecimal value.")
 
     def _get_rgb(self):
         return self._rgb
+
     def _set_rgb(self, value):
         # set name, hex and rgb
-        self.hex = rgb2hex(*value , normalised=True)
+        self.hex = rgb2hex(*value, normalised=True)
         # must reset rgb with its real value (set_hex may round the rgb)
         # in _set_hex
         self._rgb = value
-    rgb = property(_get_rgb, _set_rgb,
-            doc="getter/setter the RGB values (3-length tuple)")
+
+    rgb = property(_get_rgb, _set_rgb, doc="getter/setter the RGB values (3-length tuple)")
 
     def _get_hsv(self):
         hsv = rgb2hsv(*self.rgb)
         return hsv
+
     def _set_hsv(self, value):
         # TODO: value must be normalised
         self.rgb = hsv2rgb(*value)
-    hsv = property(_get_hsv, _set_hsv,
-            doc="getter/setter the HSV values (3-length tuple)")
+
+    hsv = property(_get_hsv, _set_hsv, doc="getter/setter the HSV values (3-length tuple)")
 
     def _get_hls(self):
         hls = rgb2hls(*self.rgb)
         return hls
+
     def _set_hls(self, value):
-        #hls = _normalise(*value, mode="hls")
-        #else:
+        # hls = _normalise(*value, mode="hls")
+        # else:
         hls = value
         self.rgb = hls2rgb(*hls)
-    hls = property(_get_hls, _set_hls,
-            doc="getter/setter the HLS values (3-length tuple)")
+
+    hls = property(_get_hls, _set_hls, doc="getter/setter the HLS values (3-length tuple)")
 
     def _get_lightness(self):
         return self.hls[1]
+
     def _set_lightness(self, lightness):
         h, l, s = self.hls
         self.hls = (h, lightness, s)
-    lightness = property(_get_lightness, _set_lightness,
-            doc="getter/setter the lightness in the HLS triplet")
+
+    lightness = property(_get_lightness, _set_lightness, doc="getter/setter the lightness in the HLS triplet")
 
     def _get_saturation_hls(self):
         return self.hls[2]
+
     def _set_saturation_hls(self, saturation):
         h, l, s = self.hls
         self.hls = (h, l, saturation)
-    saturation_hls = property(_get_saturation_hls, _set_saturation_hls,
-            doc="getter/setter the saturation in the HLS triplet")
+
+    saturation_hls = property(
+        _get_saturation_hls, _set_saturation_hls, doc="getter/setter the saturation in the HLS triplet"
+    )
 
     def _get_hue(self):
         return self.hls[0]
+
     def _set_hue(self, hue):
         h, l, s = self.hls
         self.hls = (hue, l, s)
-    hue = property(_get_hue, _set_hue,
-            doc="getter/setter the saturation in the HLS triplet")
+
+    hue = property(_get_hue, _set_hue, doc="getter/setter the saturation in the HLS triplet")
 
     def _get_red(self):
         return self.rgb[0]
+
     def _set_red(self, red):
         r, g, b = self.rgb
-        self.rgb = (red,g,b)
-    red = property(_get_red, _set_red,
-            doc="getter/setter for the red color in RGB triplet")
+        self.rgb = (red, g, b)
+
+    red = property(_get_red, _set_red, doc="getter/setter for the red color in RGB triplet")
 
     def _get_green(self):
         return self.rgb[1]
+
     def _set_green(self, green):
         r, g, b = self.rgb
         self.rgb = (r, green, b)
-    green = property(_get_green, _set_green,
-            doc="getter/setter for the green color in RGB triplet")
+
+    green = property(_get_green, _set_green, doc="getter/setter for the green color in RGB triplet")
 
     def _get_blue(self):
         return self.rgb[2]
+
     def _set_blue(self, blue):
         r, g, b = self.rgb
         self.rgb = (r, g, blue)
-    blue = property(_get_blue, _set_blue,
-            doc="getter/setter for the blue color in RGB triplet")
+
+    blue = property(_get_blue, _set_blue, doc="getter/setter for the blue color in RGB triplet")
 
     def _get_value(self):
-        return self.hls[0]
+        return self.hsv[2]
+
     def _set_value(self, value):
         h, s, v = self.hsv
         self.hsv = (h, s, value)
-    value = property(_get_value, _set_value,
-            doc="getter/setter the value in the HSV triplet")
+
+    value = property(_get_value, _set_value, doc="getter/setter the value in the HSV triplet")
 
     def _get_yiq(self):
         return colorsys.rgb_to_yiq(*self.rgb)
+
     yiq = property(_get_yiq, doc="Getter for the YIQ triplet")
 
     def __str__(self):
-        txt = 'Color {0}\n'.format(self.name)
-        txt+= '  hexa code: {0}\n'.format(self.hex)
-        txt+= '  RGB code: {0}\n'.format(self.rgb)
-        txt+= '  RGB code (un-normalised): {0}\n\n'.format([x*255 for x in self.rgb])
-        txt+= '  HSV code: {0}\n'.format(self.hsv)
-        txt+= '  HSV code: (un-normalised) {0} {1} {2}\n\n'.format(self.hsv[0]*360, self.hsv[1]*100, self.hsv[2]*100)
-        txt+= '  HLS code: {0}\n'.format(self.hls)
-        txt+= '  HLS code: (un-normalised) {0} {1} {2}\n\n'.format(self.hls[0]*360, self.hls[1]*100, self.hls[2]*100)
+        txt = "Color {0}\n".format(self.name)
+        txt += "  hexa code: {0}\n".format(self.hex)
+        txt += "  RGB code: {0}\n".format(self.rgb)
+        txt += "  RGB code (un-normalised): {0}\n\n".format([x * 255 for x in self.rgb])
+        txt += "  HSV code: {0}\n".format(self.hsv)
+        txt += "  HSV code: (un-normalised) {0} {1} {2}\n\n".format(
+            self.hsv[0] * 360, self.hsv[1] * 100, self.hsv[2] * 100
+        )
+        txt += "  HLS code: {0}\n".format(self.hls)
+        txt += "  HLS code: (un-normalised) {0} {1} {2}\n\n".format(
+            self.hls[0] * 360, self.hls[1] * 100, self.hls[2] * 100
+        )
         return txt
 
 
@@ -693,7 +731,7 @@ class Colormap(object):
         cmap = c.cmap_linear("red", "white", "green")
         c.test_colormap(cmap)
 
-    Even simpler, you can use a bicolor colormap :meth:`cmap_bicolor`. For instance 
+    Even simpler, you can use a bicolor colormap :meth:`cmap_bicolor`. For instance
     for a red to green colormap::
 
         cmap = c.cmap_bicolor("red", "green")
@@ -713,46 +751,116 @@ class Colormap(object):
     :references: matplotlib documentation and examples
         http://matplotlib.org/examples/color/colormaps_reference.html
     """
+
     def _get_colormap_mpl(self):
         try:
             from matplotlib.pyplot import colormaps as _cmaps
+
             return _cmaps()
         except:
             return []
+
     colormaps = property(_get_colormap_mpl)
 
     def _get_sequentials(self):
-        return ['Blues', 'BuGn', 'BuPu', 'GnBu', 'Greens', 'Greys', 'OrRd',
-                'Oranges', 'PuBu', 'PuBuGn', 'PuRd', 'Purples', 'RdPu',
-                'Reds', 'YlGn', 'YlGnBu', 'YlOrBr', 'YlOrRd']
+        return [
+            "Blues",
+            "BuGn",
+            "BuPu",
+            "GnBu",
+            "Greens",
+            "Greys",
+            "OrRd",
+            "Oranges",
+            "PuBu",
+            "PuBuGn",
+            "PuRd",
+            "Purples",
+            "RdPu",
+            "Reds",
+            "YlGn",
+            "YlGnBu",
+            "YlOrBr",
+            "YlOrRd",
+        ]
+
     sequentials = property(_get_sequentials)
 
     def _get_sequentials2(self):
-        return ['afmhot', 'autumn', 'bone', 'cool', 'copper',
-               'gist_heat', 'gray', 'hot', 'pink',
-               'spring', 'summer', 'winter']
+        return [
+            "afmhot",
+            "autumn",
+            "bone",
+            "cool",
+            "copper",
+            "gist_heat",
+            "gray",
+            "hot",
+            "pink",
+            "spring",
+            "summer",
+            "winter",
+        ]
+
     sequentials2 = property(_get_sequentials2)
 
     def _get_diverging(self):
-         return ['BrBG',  'PRGn',  'PiYG', 'PuOr', 'RdBu', 'RdGy', 'RdYlBu',
-                 'RdYlGn', 'Spectral', 'bwr', 'coolwarm', 'seismic']
+        return [
+            "BrBG",
+            "PRGn",
+            "PiYG",
+            "PuOr",
+            "RdBu",
+            "RdGy",
+            "RdYlBu",
+            "RdYlGn",
+            "Spectral",
+            "bwr",
+            "coolwarm",
+            "seismic",
+        ]
+
     diverging = property(_get_diverging)
 
     def _get_diverging_black(self):
-         return ['red_black_sky', 'red_black_blue', 'red_black_green', 'yellow_black_blue',
-                 'yellow_black_sky', 'red_black_orange', 'pink_black_green(w3c)'
-                 ]
+        return [
+            "red_black_sky",
+            "red_black_blue",
+            "red_black_green",
+            "yellow_black_blue",
+            "yellow_black_sky",
+            "red_black_orange",
+            "pink_black_green(w3c)",
+        ]
+
     diverging_black = property(_get_diverging_black)
 
     def _get_qualitative(self):
-        return ['Accent', 'Dark2', 'Paired', 'Pastel1', 'Pastel2',
-                'Set1', 'Set2', 'Set3']
+        return ["Accent", "Dark2", "Paired", "Pastel1", "Pastel2", "Set1", "Set2", "Set3"]
+
     qualitative = property(_get_qualitative)
 
     def _get_misc(self):
-        return ['gist_earth', 'terrain', 'ocean', 'gist_stern',
-                'brg', 'CMRmap', 'cubehelix', 'gnuplot', 'gnuplot2', 'gist_ncar',
-                'nipy_spectral', 'jet', 'rainbow', 'gist_rainbow', 'hsv', 'flag', 'prism']
+        return [
+            "gist_earth",
+            "terrain",
+            "ocean",
+            "gist_stern",
+            "brg",
+            "CMRmap",
+            "cubehelix",
+            "gnuplot",
+            "gnuplot2",
+            "gist_ncar",
+            "nipy_spectral",
+            "jet",
+            "rainbow",
+            "gist_rainbow",
+            "hsv",
+            "flag",
+            "prism",
+        ]
+
     misc = property(_get_misc)
 
     def plot_rgb_from_hex_list(self, cols):
@@ -775,14 +883,15 @@ class Colormap(object):
 
         """
         import pylab
-        red = [hex2rgb(x)[0]/255. for x in cols]
-        blue = [hex2rgb(x)[2]/255. for x in cols]
-        green = [hex2rgb(x)[1]/255. for x in cols]
+
+        red = [hex2rgb(x)[0] / 255.0 for x in cols]
+        blue = [hex2rgb(x)[2] / 255.0 for x in cols]
+        green = [hex2rgb(x)[1] / 255.0 for x in cols]
         x = pylab.linspace(0, 1, len(cols))
         pylab.clf()
-        pylab.plot(x, red, 'ro-', alpha=0.5)
-        pylab.plot(x, green, 'gs-', alpha=0.5, markersize=15)
-        pylab.plot(x, blue, 'bx-', alpha=0.5, markersize=15)
+        pylab.plot(x, red, "ro-", alpha=0.5)
+        pylab.plot(x, green, "gs-", alpha=0.5, markersize=15)
+        pylab.plot(x, blue, "bx-", alpha=0.5, markersize=15)
         pylab.ylim([-0.1, 1.1])
 
     def cmap_bicolor(self, color1, color2, reverse=False, N=256):
@@ -797,9 +906,7 @@ class Colormap(object):
         """
         c1 = Color(color1)
         c2 = Color(color2)
-        dico = {'red': [c1.red, c2.red],
-                'green':[c1.green, c2.green],
-                'blue':[c1.blue, c2.blue]}
+        dico = {"red": [c1.red, c2.red], "green": [c1.green, c2.green], "blue": [c1.blue, c2.blue]}
         return self.cmap(dico, reverse=reverse, N=N)
 
     def cmap_linear(self, color1, color2, color3, reverse=False, N=256):
@@ -814,9 +921,11 @@ class Colormap(object):
         c1 = Color(color1)
         c2 = Color(color2)
         c3 = Color(color3)
-        dico = {'red': [c1.red, c2.red, c3.red],
-                'green':[c1.green, c2.green, c3.green],
-                'blue':[c1.blue, c2.blue, c3.blue]}
+        dico = {
+            "red": [c1.red, c2.red, c3.red],
+            "green": [c1.green, c2.green, c3.green],
+            "blue": [c1.blue, c2.blue, c3.blue],
+        }
 
         return self.cmap(dico, reverse=reverse, N=N)
 
@@ -833,24 +942,24 @@ class Colormap(object):
         if colors in self.colormaps:
             if reverse and colors.endswith("_r") is False:
                 colors += "_r"
-            from matplotlib.cm import get_cmap
-            return get_cmap(colors)
+            from matplotlib import colormaps
+            return colormaps[colors]
         # custom ones
         elif colors in self.diverging_black:
             c1, c2, c3 = colors.split("_")
             # special case of sky, which does not exists
             c3 = c3.replace("sky", "deep sky blue")
             return self.cmap_linear(c1, c2, c3)
-        elif colors == 'heat':
+        elif colors == "heat":
             return self.get_cmap_heat()
-        elif colors == 'heat_r':
+        elif colors == "heat_r":
             return self.get_cmap_heat_r()
 
-
         # Keep these dependencies inside the function to allow
         # installation of colormap without those dependencies
         # FIXME remove numpy dependencies
         import numpy as np
+
         # extracted from R, heat.colors(20)
 
         if reverse:
@@ -858,17 +967,16 @@ class Colormap(object):
                 colors[k].reverse()
 
         # If index not given, RGB colors are evenly-spaced in colormap.
-        index = np.linspace(0, 1, len(colors['red']))
+        index = np.linspace(0, 1, len(colors["red"]))
 
         # Adapt color_data to the form expected by LinearSegmentedColormap.
-        color_data = dict((key, [(x, y, y) for x, y in zip(index, value)])
-                 for key, value in list(colors.items()))
+        color_data = dict((key, [(x, y, y) for x, y in zip(index, value)]) for key, value in list(colors.items()))
 
         import matplotlib
-        f = matplotlib.colors.LinearSegmentedColormap
-        m = f('my_color_map', color_data, N)
-        return m
 
+        f = matplotlib.colors.LinearSegmentedColormap
+        m = f("my_color_map", color_data, N)
+        return m
 
     def get_cmap_heat(self):
         """Return a heat colormap matplotlib-compatible colormap
@@ -890,19 +998,15 @@ class Colormap(object):
 
         """
         return self.cmap(
-                {   'blue':[0, 0, 0, 0, 1],
-                    'green':[0, .35, .7, 1, 1],
-                    'red':[1, 1, 1, 1, 1]}, reverse=False)
+            {"blue": [0, 0, 0, 0, 1], "green": [0, 0.35, 0.7, 1, 1], "red": [1, 1, 1, 1, 1]}, reverse=False
+        )
 
     def get_cmap_heat_r(self):
         """Return a heat colormap matplotlib-compatible colormap
 
         Same as :meth:`get_cmap_heat` but reversed
         """
-        return self.cmap(
-                {   'blue':[0, 0, 0, 0, 1],
-                    'green':[0, .35, .7, 1, 1],
-                    'red':[1, 1, 1, 1, 1]}, reverse=True)
+        return self.cmap({"blue": [0, 0, 0, 0, 1], "green": [0, 0.35, 0.7, 1, 1], "red": [1, 1, 1, 1, 1]}, reverse=True)
 
     def get_cmap_rainbow(self):
         """colormap similar to rainbow colormap from R
@@ -912,16 +1016,18 @@ class Colormap(object):
 
         """
         return self.cmap(
-                {   'blue': [0, 0, 0, 1, 1, 1, 0],
-                    'green':[0, 1, 1, 1, 0, 0, 0],
-                    'red':  [1, 1, 0, 0, 0, 1, 1]}, reverse=False)
-
+            {"blue": [0, 0, 0, 1, 1, 1, 0], "green": [0, 1, 1, 1, 0, 0, 0], "red": [1, 1, 0, 0, 0, 1, 1]}, reverse=False
+        )
 
     def get_cmap_red_green(self):
         return self.cmap(
-                {   'green': [0, 0.4, 0.6, .75, .8, .9, 1, .9, .8, .6],
-                    'blue' : [0, .4, .6, .75, .8, .7, .6, .35, .17, .1],
-                    'red':   [1, 1, 1, 1, 1, .9, .8, .6, .3, .1]}, reverse=True)
+            {
+                "green": [0, 0.4, 0.6, 0.75, 0.8, 0.9, 1, 0.9, 0.8, 0.6],
+                "blue": [0, 0.4, 0.6, 0.75, 0.8, 0.7, 0.6, 0.35, 0.17, 0.1],
+                "red": [1, 1, 1, 1, 1, 0.9, 0.8, 0.6, 0.3, 0.1],
+            },
+            reverse=True,
+        )
 
     def test_colormap(self, cmap=None):
         """plot one colormap for testing
@@ -933,12 +1039,13 @@ class Colormap(object):
             cmap = self.get_cmap_heat()
         import numpy as np
         from pylab import clf, pcolor, colorbar, show, linspace, axis
+
         A, B = np.meshgrid(linspace(0, 10, 100), linspace(0, 10, 100))
         clf()
-        pcolor((A-5)**2+(B-5)**2, cmap=cmap)
+        pcolor((A - 5) ** 2 + (B - 5) ** 2, cmap=cmap)
         colorbar()
         show()
-        axis('off')
+        axis("off")
 
     def plot_colormap(self, cmap_list=None):
         """cmap_list list of valid cmap or name of a set (sequential,
@@ -959,32 +1066,33 @@ class Colormap(object):
         from pylab import subplots
 
         if isinstance(cmap_list, str):
-            if cmap_list in ['sequentials','sequentials2','qualitative',
-                             'misc','diverging', 'diverging_black']:
+            if cmap_list in ["sequentials", "sequentials2", "qualitative", "misc", "diverging", "diverging_black"]:
                 cmap_list = getattr(self, cmap_list)
             else:
                 cmap_list = [cmap_list]
         if isinstance(cmap_list, list) is not True:
-            raise TypeError("""input must be a list of srtings or a single string. Each string should be found. For a user-defined cmap, use test_colormap""")
+            raise TypeError(
+                """input must be a list of srtings or a single string. Each string should be found. For a user-defined cmap, use test_colormap"""
+            )
         for this in cmap_list:
             if this not in self.colormaps and this not in self.diverging_black:
                 raise ValueError("unknown colormap name. Please check valid names in colormaps attribute")
 
         nrows = len(cmap_list)
 
-        gradient = [x/255. for x in range(0,256)]
+        gradient = [x / 255.0 for x in range(0, 256)]
         gradient = [gradient, gradient]
-        #np.vstack((gradient, gradient))
+        # np.vstack((gradient, gradient))
 
         fig, axes = subplots(nrows=nrows)
         fig.subplots_adjust(top=0.95, bottom=0.05, left=0.05, right=0.8)
 
         for ax, name in zip(axes, cmap_list):
-            ax.imshow(gradient, aspect='auto', cmap=self.cmap(name))
+            ax.imshow(gradient, aspect="auto", cmap=self.cmap(name))
             pos = list(ax.get_position().bounds)
             x_text = pos[2] + 0.08
-            y_text = pos[1] + pos[3]/2.
-            fig.text(x_text, y_text, name, va='center', ha='left', fontsize=10)
+            y_text = pos[1] + pos[3] / 2.0
+            fig.text(x_text, y_text, name, va="center", ha="left", fontsize=10)
 
         # Turn off *all* ticks & spines, not just the ones with colormaps.
         for ax in axes:
