@@ -10,19 +10,19 @@
 #  See accompanying file LICENSE.txt or copy at
 #      http://www.gnu.org/licenses/gpl-3.0.html
 #
-#  website: 
+#  website:
 #
 ##############################################################################
 from colormap import Colormap
 
-__all__ = ['cmap_builder']
+__all__ = ["cmap_builder"]
 
 
 def cmap_builder(name, name2=None, name3=None):
     """return a colormap object compatible with matplotlib
 
-    If only parameter **name** is provided, it should be a known matplotlib 
-    colormap name (e.g., jet). If **name2** is provided, then a new colormap 
+    If only parameter **name** is provided, it should be a known matplotlib
+    colormap name (e.g., jet). If **name2** is provided, then a new colormap
     is created going from the color **name** to the color **name2** with a
     linear scale. Finally, if **name3** is provided, a linear scaled colormap
     is built from color **name** to color **name3** with the intermediate color
@@ -45,9 +45,9 @@ def cmap_builder(name, name2=None, name3=None):
         return c.cmap_linear(name, name2, name3)
     elif name and name2:
         return c.cmap_bicolor(name, name2)
-    elif name == 'heat':
+    elif name == "heat":
         return c.get_cmap_heat()
-    elif name == 'heat_r':
+    elif name == "heat_r":
         return c.get_cmap_heat_r()
     # matplotlic colormaps
     elif name in c.colormaps:
@@ -59,8 +59,7 @@ def cmap_builder(name, name2=None, name3=None):
         name1, name2, name3 = name.split("_")
         return c.cmap_linear(name1, name2, name3)
     else:
-        #valid = c.colormaps + c.diverging_black
+        # valid = c.colormaps + c.diverging_black
         txt = "name provided {0} is not recognised. ".format(name)
         txt += "\n valid name can be found in colormap.colormap_names"
         raise ValueError(txt)
-
